package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WmsImportResultMapper;
import com.ruoyi.system.domain.WmsImportResult;
import com.ruoyi.system.service.IWmsImportResultService;

/**
 * 成品查询结果(数据同步)Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-06-19
 */
@Service
public class WmsImportResultServiceImpl implements IWmsImportResultService 
{
    @Autowired
    private WmsImportResultMapper wmsImportResultMapper;

    /**
     * 查询成品查询结果(数据同步)
     * 
     * @param model 成品查询结果(数据同步)主键
     * @return 成品查询结果(数据同步)
     */
    @Override
    public WmsImportResult selectWmsImportResultByModel(String model)
    {
        return wmsImportResultMapper.selectWmsImportResultByModel(model);
    }

    /**
     * 查询成品查询结果(数据同步)列表
     * 
     * @param wmsImportResult 成品查询结果(数据同步)
     * @return 成品查询结果(数据同步)
     */
    @Override
    public List<WmsImportResult> selectWmsImportResultList(WmsImportResult wmsImportResult)
    {
        return wmsImportResultMapper.selectWmsImportResultList(wmsImportResult);
    }

    /**
     * 新增成品查询结果(数据同步)
     * 
     * @param wmsImportResult 成品查询结果(数据同步)
     * @return 结果
     */
    @Override
    public int insertWmsImportResult(WmsImportResult wmsImportResult)
    {
        return wmsImportResultMapper.insertWmsImportResult(wmsImportResult);
    }

    /**
     * 修改成品查询结果(数据同步)
     * 
     * @param wmsImportResult 成品查询结果(数据同步)
     * @return 结果
     */
    @Override
    public int updateWmsImportResult(WmsImportResult wmsImportResult)
    {
        wmsImportResult.setUpdateTime(DateUtils.getNowDate());
        return wmsImportResultMapper.updateWmsImportResult(wmsImportResult);
    }

    /**
     * 批量删除成品查询结果(数据同步)
     * 
     * @param models 需要删除的成品查询结果(数据同步)主键
     * @return 结果
     */
    @Override
    public int deleteWmsImportResultByModels(String[] models)
    {
        return wmsImportResultMapper.deleteWmsImportResultByModels(models);
    }

    /**
     * 删除成品查询结果(数据同步)信息
     * 
     * @param model 成品查询结果(数据同步)主键
     * @return 结果
     */
    @Override
    public int deleteWmsImportResultByModel(String model)
    {
        return wmsImportResultMapper.deleteWmsImportResultByModel(model);
    }
}
